@@ -366,3 +366,31 @@ class BaseClient(object):
             data.append(dp)
 
         return data
+
+    def dates(self):
+        """Returns a list of dates in local time"""
+        # set up storage
+        dates = []
+
+        # if latest, use date in local time
+        if self.options['latest']:
+            local_now = pytz.utc.localize(datetime.utcnow()).astimezone(pytz.timezone(self.TZ_NAME))
+            if local_now.date() != (local_now - timedelta(minutes=30)).date():
+                dates.append((local_now - timedelta(minutes=30)).date())
+            dates.append(local_now.date())
+
+        # if start and end, use all dates in range
+        elif self.options['start_at'] and self.options['end_at']:
+            local_start = self.options['start_at'].astimezone(pytz.timezone(self.TZ_NAME))
+            local_end = self.options['end_at'].astimezone(pytz.timezone(self.TZ_NAME))
+            this_date = local_start.date()
+            while this_date <= local_end.date():
+                dates.append(this_date)
+                this_date += timedelta(days=1)
+
+        # have to have some sort of dates
+        else:
+            raise ValueError('Either latest must be True, or start_at and end_at must both be provided.')
+
+        # return
+        return dates
